@@ -1,5 +1,3 @@
-from . import ctxlogger as logger
-from .defs import KEY_CID, KEY_AUTH, KEY_ID
 import time
 from fastapi import FastAPI, Request
 from fastapi.responses import JSONResponse, PlainTextResponse
@@ -7,7 +5,7 @@ from starlette.exceptions import HTTPException as StarletteHTTPException
 from fastapi.encoders import jsonable_encoder
 from fastapi.middleware.cors import CORSMiddleware
 import prometheus_client as pc
-import uuid
+from .ctx import Ctx
 
 c = pc.Counter('nbapi_request_count', 'Count the total number of incoming request', ['path', 'status_code', 'cid'])
 g = pc.Gauge('nbapi_request_duration', 'Gauge the duration of incoming request', ['path', 'status_code', 'cid'])
@@ -31,13 +29,10 @@ class NBApi(FastAPI):
 
         async def http_middleware(request: Request, call_next):
             ts = time.time()
-            request.state.ctx = {}
-            request.state.ctx[KEY_ID] = str(uuid.uuid4())
-            request.state.ctx[KEY_CID] = 'unknown'
-            request.state.ctx[KEY_AUTH] = request.headers['authorization']
+            request.state.ctx = Ctx(auth=request.headers.get('authorization'))
             resp = await call_next(request)
-            c.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.ctx[KEY_CID]).inc()
-            g.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.ctx[KEY_CID]).set(time.time() - ts)
+            c.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.ctx.cid).inc()
+            g.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.ctx.cid).set(time.time() - ts)
             return resp
 
         self.middleware('http')(http_middleware)
@@ -48,7 +43,7 @@ class NBApi(FastAPI):
         self.get('/metrics', include_in_schema=False)(metrics)
 
         async def handle_httperror(rec: Request, exc: StarletteHTTPException):
-            logger.error(rec.state.ctx, exc)
+            rec.state.ctx.error(exc)
             return JSONResponse(
                 status_code=exc.status_code,
                 content=jsonable_encoder({'status': 'failed', 'code': f'{exc.status_code}'}),
@@ -56,7 +51,7 @@ class NBApi(FastAPI):
         self.exception_handler(StarletteHTTPException)(handle_httperror)
 
         async def auth_error(rec: Request, exc: AuthError):
-            logger.error(rec.state.ctx, exc)
+            rec.state.ctx.error(exc)
             return JSONResponse(
                 status_code=401,
                 content=jsonable_encoder({'status': 'failed', 'code': '401'}),
@@ -64,7 +59,7 @@ class NBApi(FastAPI):
         self.exception_handler(AuthError)(auth_error)
 
         async def handle_valueerror(rec: Request, exc: ValueError):
-            logger.error(rec.state.ctx, exc)
+            rec.state.ctx.error(exc)
             return JSONResponse(
                 status_code=400,
                 content=jsonable_encoder({'status': 'failed', 'code': '400'}),
@@ -72,7 +67,7 @@ class NBApi(FastAPI):
         self.exception_handler(ValueError)(handle_valueerror)
 
         async def handle_exception(rec: Request, exc: Exception):
-            logger.error(rec.state.ctx, exc)
+            rec.state.ctx.error(exc)
             return JSONResponse(
                 status_code=500,
                 content=jsonable_encoder({'status': 'failed', 'code': '500', 'msg': f'{str(exc)}'}),
